import { CronJob } from "cron";
import { getRandomInt } from "lib/utils";
import config from "config";
import client from "lib/client";
import {
	ActionRowBuilder,
	ButtonBuilder,
	ButtonStyle,
	type CacheType,
	type Interaction,
} from "discord.js";

export class WaterMeService {
	waterLevel: number;

	private thirsty = 3 as const;
	private enough = 10 as const;

	constructor() {
		this.waterLevel = 0;
	}

	getReply() {
		const thirstyReplies = [
			"... wow das wars schon??? ich brauche noch mehr wasser :(",
			"dankeeeee!!!! ich waer fast verdurstet :(((",
			"*roelpssssss*",
		];

		const fullReplies = [
			"langsam reicht es :o",
			"poah, das hat gut getan",
			"das ist krass :3",
		];

		const tooMuchReplies = [
			"ES REICHT!!!!",
			"bitte hoer auf, ich platze gleich :(",
		];

		if (this.waterLevel <= this.thirsty) {
			return thirstyReplies[getRandomInt(0, thirstyReplies.length - 1)];
		}
		if (this.waterLevel > this.thirsty && this.waterLevel <= this.enough) {
			return fullReplies[getRandomInt(0, fullReplies.length - 1)];
		}
		if (this.waterLevel > this.enough) {
			return tooMuchReplies[getRandomInt(0, tooMuchReplies.length - 1)];
		}
	}

	async isThirsty() {
		const channels = client.channels;

		const channel = channels.cache.get(config.discord.channelId);

		if (
			channel?.isTextBased &&
			channel?.isSendable() &&
			this.waterLevel <= this.thirsty
		) {
			await channel.send({ content: "ich brauche wasser :(" });
		}
	}

	waterMe() {
		const reply = this.getReply();

		this.waterLevel++;
		console.log(this.waterLevel);

		return {
			reply,
		};
	}

	async handleInteraction(interaction: Interaction<CacheType>) {
		const result = this.waterMe();

		const moreButton = new ButtonBuilder()
			.setCustomId("moreWater")
			.setLabel("mehr")
			.setStyle(ButtonStyle.Secondary);

		const row = new ActionRowBuilder().addComponents(moreButton);

		if (interaction.isChatInputCommand()) {
			await interaction.reply({
				content: result.reply,
				// biome-ignore lint/suspicious/noExplicitAny: <explanation>
				components: [row as any],
			});
		} else if (interaction.isButton()) {
			await interaction.reply({
				content: result.reply,
			});
		}
	}
}
